@@ -33,9 +33,14 @@ def validate_aliases(aliases):
 
     for alias_rec in aliases:
         namespace, alias = alias_rec["namespace"], alias_rec["alias"]
+
         if invalid_alias_chars_re.search(alias):
             raise RuntimeError(f"alias {alias} contains invalid char (one of {invalid_alias_chars_re})")
+
         if namespace.startswith("Ensembl"):
+            if alias.startswith("ENS") and "." not in alias:
+                raise RuntimeError(f"{namespace} alias {alias} is unversioned")
+        elif namespace in ("NCBI", "refseq"):
             if "." not in alias:
                 raise RuntimeError(f"{namespace} alias {alias} is unversioned")
     return True
